@@ -133,7 +133,7 @@ pub async fn update_fulfillment_type_handler<T: Context + Send>(
 pub async fn initiate_payment_handler<T: Context + Send>(
     ctx: &mut T,
     checkout_id: &str,
-    args: <T as PaymentProcessor>::InitiateArgs,
+    args: Option<<T as PaymentProcessor>::ProcessArgs>,
 ) -> Result<Checkout, Error> {
     let maybe_co = ctx.get_checkout_for_update(&checkout_id).await?;
     if maybe_co.is_none() {
