@@ -38,6 +38,7 @@ pub struct Checkout {
     pub shipping_quotes: Vec<ShippingQuote>,
     pub invoice: Option<Invoice>,
     pub payment_id: Option<String>,
+    pub order_id: Option<String>,
 }
 
 #[async_trait]
@@ -68,6 +69,7 @@ impl Checkout {
             shipping_quotes: vec![],
             invoice: None,
             payment_id: None,
+            order_id: None,
         };
 
         ctx.create_checkout(&co).await?;
@@ -130,6 +132,7 @@ impl Checkout {
     }
 
     async fn enter_completed_state(&mut self) -> Result<(), Error> {
+        // TODO: create new order in the PendingConfirmation or Confirmed state and set checkout's order_id field
         Ok(self.state = State::Completed)
     }
 }
