@@ -8,6 +8,7 @@ use crate::context::Context;
 use crate::error::{new_application_error, Error};
 use crate::internal_context::InternalContext;
 use crate::money::Money;
+use crate::order::Order;
 
 pub mod handlers;
 
@@ -31,10 +32,12 @@ pub enum PaymentState<ProcessArgs> {
 #[derive(Serialize, Deserialize, JsonSchema)]
 pub enum InitiatorId {
     Checkout(String),
+    Order(String),
 }
 
 pub enum Initiator<'a> {
     Checkout(&'a mut Checkout),
+    Order(&'a mut Order),
 }
 
 #[async_trait]
@@ -164,6 +167,7 @@ async fn new<'a, C: Context + Send>(
         state: PaymentState::Idle,
         initiator_id: match &initiator {
             Initiator::Checkout(co) => InitiatorId::Checkout(co.id.clone()),
+            Initiator::Order(od) => InitiatorId::Order(od.id.clone()),
         },
         charge_amount,
         data: PaymentData {
@@ -191,9 +195,15 @@ async fn new<'a, C: Context + Send>(
         match payment.state {
             PaymentState::Succeeded => match initiator {
                 Initiator::Checkout(co) => co.complete(ctx).await?,
+                Initiator::Order(_) => {
+                    // TODO: transition order to PendingConfirmation or Confirmed
+                }
             },
             PaymentState::Cancelled => match initiator {
                 Initiator::Checkout(co) => co.revert(ctx).await?,
+                Initiator::Order(_) => {
+                    // TODO: transition order to Cancelled
+                }
             },
             _ => {}
         }
@@ -266,9 +276,17 @@ pub async fn process<'a, C: Context + Send>(
             match payment.state {
                 PaymentState::Succeeded => match initiator {
                     Initiator::Checkout(co) => co.complete(ctx).await,
+                    Initiator::Order(_) => {
+                        // TODO: transition order to PendingConfirmation or Confirmed
+                        Ok(())
+                    }
                 },
                 PaymentState::Cancelled => match initiator {
                     Initiator::Checkout(co) => co.revert(ctx).await,
+                    Initiator::Order(_) => {
+                        // TODO: transition order to Cancelled
+                        Ok(())
+                    }
                 },
                 _ => Ok(()),
             }
@@ -302,6 +320,10 @@ pub async fn cancel<'a, C: Context + Send>(
 
             match initiator {
                 Initiator::Checkout(co) => co.revert(ctx).await,
+                Initiator::Order(_) => {
+                    // TODO: transition order to Cancelled
+                    Ok(())
+                }
             }
         }
         PaymentState::Processing(_) => Err(new_application_error(
